<?php

/*
 * LMS version 1.10.2 Roham
 *
 *  (C) Copyright 2001-2007 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: balancedel.php,v 1.12.2.1 2007/08/17 13:15:20 alec Exp $
 */

if($_GET['id'])
{
	$LMS->DelBalance($_GET['id']);
}
elseif(sizeof($_POST['marks']))
{
	foreach($_POST['marks'] as $markid => $junk)
		if ($junk)
			$ids[] = $markid;
	sort($ids);
	foreach($ids as $idx => $cashid)
	{
		$LMS->DelBalance($cashid);
	}
}

header('Location: ?'.$SESSION->get('backto'));

?>
